#
# spec file for package emacs-haskell-mode
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           emacs-haskell-mode
Version:        16.1
Release:        lp151.2.65
Summary:        Haskell mode for EMACS
License:        GPL-3.0-or-later
Group:          Productivity/Text/Editors
URL:            http://haskell.github.io/haskell-mode/
Source:         https://github.com/haskell/haskell-mode/archive/v%{version}.tar.gz#/haskell-mode-%{version}.tar.gz
Source1:        suse-start-haskell-mode.el
# PATCH-FIX-UPSTREAM GHCi8.2.1-response.patch ptrommler@icloud.com -- Accept new GHCi response when reloading modules
Patch1:         GHCi8.2.1-response.patch
BuildRequires:  emacs-nox
BuildRequires:  git
BuildRequires:  makeinfo
Requires:       emacs
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}
BuildArch:      noarch

%description
Haskell-mode is a major Emacs mode for editing Haskell source code. It
provides syntax highlighting and automatic indentation and comes with
inf-haskell which allows interaction with an inferior Haskell interactive loop
such as the one of Hugs or GHCi.

%define _sitedir %{_datadir}/emacs/site-lisp
%define _lispdir %{_sitedir}/haskell-mode

%prep
%setup -q -n haskell-mode-%{version}
%patch1 -p1

%build
make %{?_smp_mflags}

%install
emacs_version=$(emacs -Q --batch --eval '(princ emacs-version)')
install -pm 755 -d %{buildroot}%{_lispdir}/haskell-mode
install -pm 644 build-$emacs_version/*.elc %{buildroot}%{_lispdir}/
install -pm 644 haskell-mode-autoloads.el %{buildroot}%{_lispdir}/haskell-mode-autoloads.el
install -pm 644 %{SOURCE1} %{buildroot}%{_sitedir}/suse-start-haskell-mode.el
install -D -pm 644 haskell-mode.info %{buildroot}%{_infodir}/haskell-mode.info

%post
%install_info --info-dir=%{_infodir} %{_infodir}/haskell-mode.info

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/haskell-mode.info

%files
%dir %{_lispdir}
%doc COPYING NEWS README.md
%{_infodir}/haskell-mode.info%{ext_info}
%{_lispdir}/*.elc
%{_lispdir}/haskell-mode-autoloads.el
%{_sitedir}/suse-start-haskell-mode.el

%changelog
* Fri Apr 13 2018 psimons@suse.com
- Fix homepage and download URLs.
- Re-format spec file with recent spec-cleaner.
* Mon Mar 26 2018 ptrommler@icloud.com
- update to 16.1
  * support Liquid Haskell annotations
  * support Yesod rules quasi quotes
  * implement electric characters
- add patch GHCi8.2.1-response.patch
  * fix module reload in GHCi interactive sessions for GHC 8.2.1
  and later
* Sat Jul 16 2016 psimons@suse.com
- Fix group tag.
* Fri Feb 26 2016 peter.trommler@ohm-hochschule.de
- keep haskell-mode-autoloads.el
* Thu Feb 25 2016 peter.trommler@ohm-hochschule.de
- enable automatic loading with suse-start-*
* Thu Feb 18 2016 psimons@suse.com
- update to version 13.18
* Wed May  6 2015 mimi.vx@gmail.com
- update to version 13.12
- Added haskell-bot.el
- Added support for cabal repl build targets
- Automatically add import lines via Hoogle
- Automatically add package to cabal file
- Added w3m-haddock.el
- Added debugger mode
- Added preliminary :present support
- Added haskell-sort-imports
- Added haskell-complete-module
- Support if and multi-way if in indentation
- Add support to generate tags on windows
- Add haskell-language-extensions variable
- Improve haskell-simple-indent mode
- Improve test cases
  * Changes in 13.10
- Small fix for haskell-simple-indent: Certain indentation situations
  cause valname-string to be nil, which haskell-trim did not handle
  gracefully (naturally, since nil != "").
- Luke Hoersten's Shnippet merged in under snippets/.
- haskell-presentation-mode is now a haskell-mode derived mode.
- Small improvement to haskell-process-do-info (works on constructors
  now and underscored names).
- Add haskell-indent-spaces configuration variable.
- The command string to run cabal commands is slightly more
  configurable. See: C-h f haskell-process-do-cabal-format-string
  * Changes in 13.8
- Make `haskell-simple-indent-mode' a proper minor mode with `SInd` as
  mode-line lighter
- Support popular "λ> " prompt in inf-haskell by default
- Hide internal `*print-haskell-mode*' buffers
  (used when `haskell-interactive-mode-eval-mode' is active)
- Add tab-completion support for haskell-interactive-mode
  (requires `:complete' command support in GHCi)
- Add support to `haskell-process-do-info` to perform `:browse!` query
  on module name when called on import statement line
- `haskell-decl-scan-mode':
  - New customize group `haskell-decl-scan'
  - New flag `haskell-decl-scan-bindings-as-variables' for controlling
    whether to put value bindings into the "Variables" category.
  - New flag `haskell-decl-scan-add-to-menubar' for controlling
    whether to add "Declarations" menu entry to menu bar.
  - New manual section node `(haskell-mode)haskell-decl-scan-mode'
- Add support for [[http://www.haskell.org/ghc/docs/latest/html/users_guide/syntax-extns.html#lambda-case][LambdaCase]] syntax extension to `haskell-indentation`
- Change `haskell-indentation-mode' to never jump back a whole line
  when pressing DEL.  The old behavior can be restored by setting
  `haskell-indentation-delete-backward-jump-line' to t
- New convenience function `haskell-cabal-visit-file' for locating and
  visiting most likely `.cabal` file associated with current buffer
- Add support for [[http://www.haskell.org/ghc/docs/latest/html/users_guide/syntax-extns.html#package-import][PackageImports]] and [[http://www.haskell.org/ghc/docs/latest/html/users_guide/syntax-extns.html#safe-imports-ext][SafeHaskell]] syntax extensions to
  `haskell-decl-scan-mode' parser
- Add `turn-{on,off}-haskell-doc' commands as aliases for the existing
  `turn-{on,off}-haskell-doc-mode' commands
- Add support for "cabal repl" process type to `haskell-interactive-mode'
- Add new Haskell compilation sub-mode and associated `haskell-compile'
  command
* Sun Mar  2 2014 peter.trommler@ohm-hochschule.de
- create and install autoloads file
* Sat Mar  1 2014 peter.trommler@ohm-hochschule.de
- install init file
* Fri Dec 27 2013 peter.trommler@ohm-hochschule.de
- initial package (version 13.07)
